@@ -42,7 +42,7 @@ public:
         return m_openFileCalled;
     }
 protected:
-    /*reimp*/ bool openFile()
+    bool openFile() Q_DECL_OVERRIDE
     {
         m_openFileCalled = true;
         return true;
@@ -56,6 +56,7 @@ void PartTest::testAutoDeletePart()
     KParts::Part *part = new TestPart(0, 0);
     QPointer<KParts::Part> partPointer(part);
     delete part->widget();
+    QCoreApplication::sendPostedEvents(0, QEvent::DeferredDelete);
     QVERIFY(partPointer.isNull());
 }
 
@@ -65,6 +66,7 @@ void PartTest::testAutoDeleteWidget()
     QPointer<KParts::Part> partPointer(part);
     QPointer<QWidget> widgetPointer(part->widget());
     delete part;
+    QCoreApplication::sendPostedEvents(0, QEvent::DeferredDelete);
     QVERIFY(widgetPointer.isNull());
 }
 
